@@ -30,9 +30,13 @@ function local_filter_get() {
    }
 
    $file = "$path/$FILTERFILE";
-   if (!file_exists($file))
-      touch($file);
-   return $file;
+   $localfile = "/tmp/$FILTERFILE.$username";
+   if (file_exists($file))
+      copy($file, $localfile);
+   else
+      touch($localfile);
+
+   return $localfile;
 }
 
 function local_filter_exists() {
@@ -81,7 +85,10 @@ function ftp_filter_get() {
    global $username, $FILTERDIR, $FILTERFILE, $VIRTUAL_DOMAINS, $SEPERATOR;
    if ($VIRTUAL_DOMAINS) 
      list($user,$domain) = split($SEPERATOR,$username);
-   else $user = $username;
+   else {
+     $user = $username;
+     $domain = '';
+   }
    $path = preg_replace(array('/\[DOMAIN\]/','/\[USERNAME\]/'),array($domain,$user),$FILTERDIR);
    $filtername = "$path/$FILTERFILE";
    $localfile = "/tmp/$FILTERFILE.$username";
@@ -101,7 +108,10 @@ function ftp_filter_put($file) {
    global $username, $FILTERDIR, $FILTERFILE, $VIRTUAL_DOMAINS, $SEPERATOR;
    if ($VIRTUAL_DOMAINS) 
      list($user,$domain) = split($SEPERATOR,$username);
-   else $user = $username;
+   else {
+      $user = $username;
+      $domain = '';
+   }
    $path = preg_replace(array('/\[DOMAIN\]/','/\[USERNAME\]/'),array($domain,$user),$FILTERDIR);
    $filtername = "$path/$FILTERFILE";
    _ftp_put($file,$filtername);
@@ -188,11 +198,17 @@ function procmail_write_filter_recipie($fd, $action, $field, $string, $folder,
        $procaction2 = "c:";
 
    $procaction1 = $procaction2;
-   if ($USE_MAILDIRS) $suffix = '/';
 
-   $df = preg_replace("/\./",'[\\.]?',$default_folder_prefix);
-   $folder = preg_replace("/$df/",'',$folder);
-   $folder = "$optional_delimiter$folder$suffix";
+   if ($USE_MAILDIRS) {
+      $df = preg_replace("/\./",'[\\.]?',$default_folder_prefix);
+      $folder = preg_replace("/$df/",'',$folder);
+      $folder = $folder.'/';
+   }
+
+   $folder = '$MAILDIR'.$optional_delimiter.$folder;
+
+   //escape spaces
+   $folder = preg_replace('/\s/', '\ ', $folder);
 
    if ($toFolder == 'on' && $toAddress == 'on') {
       $procaction1 = 'c:';
